@@ -10,6 +10,7 @@ from maitai._config import config
 from maitai._maitai_client import MaitaiClient
 from maitai._utils import chat_completion_chunk_to_response
 from maitai_common.utils.types import EvaluateCallback
+from maitai_common.version import version
 from maitai_gen.chat import ChatCompletionChunk, ChatCompletionParams, ChatCompletionResponse, EvaluateRequest, EvaluateResponse, EvaluationContentType
 
 
@@ -38,7 +39,7 @@ class Evaluator(MaitaiClient):
             raise Exception('application_id or application_ref_name must be provided')
         eval_request: EvaluateRequest = cls.create_eval_request(application_id, application_ref_name, session_id, reference_id, action_type, content_type, content)
         if completion_params is not None:
-            eval_request.chat_completion_request = cls.create_inference_request(application_ref_name, session_id, reference_id, action_type, False, True, completion_params)
+            eval_request.chat_completion_request = cls.create_inference_request(application_ref_name, session_id, reference_id, action_type, False, True, completion_params, callback)
             if chat_completion_chunk is not None:
                 chat_completion_response = chat_completion_chunk_to_response(chat_completion_chunk, content)
             eval_request.chat_completion_response = chat_completion_response
@@ -56,7 +57,7 @@ class Evaluator(MaitaiClient):
             raise Exception('application_id or application_ref_name must be provided')
         eval_request: EvaluateRequest = cls.create_eval_request(application_id, application_ref_name, session_id, reference_id, action_type, content_type, content, partial=partial)
         if completion_params is not None:
-            eval_request.chat_completion_request = cls.create_inference_request(application_ref_name, session_id, reference_id, action_type, False, True, completion_params)
+            eval_request.chat_completion_request = cls.create_inference_request(application_ref_name, session_id, reference_id, action_type, False, True, completion_params, callback)
             if chat_completion_chunk is not None:
                 chat_completion_response = chat_completion_chunk_to_response(chat_completion_chunk, content)
             eval_request.chat_completion_response = chat_completion_response
@@ -64,11 +65,11 @@ class Evaluator(MaitaiClient):
         cls.run_async(cls.send_evaluation_request_async(eval_request, callback))
 
     @classmethod
-    def evaluate_realtime(cls, session_id, reference_id, action_type, content_type, content, application_ref_name, partial, fault_description, sentinel_id):
+    def stream_correction(cls, session_id, reference_id, action_type, content_type, content, application_ref_name, partial, fault_description, sentinel_id):
         eval_request: EvaluateRequest = cls.create_eval_request(None, application_ref_name, session_id, reference_id, action_type, content_type, content, partial=partial,
                                                                 fault_description=fault_description)
         eval_request.sentinel_id = sentinel_id
-        return cls.send_realtime_eval_request(eval_request)
+        return cls.send_stream_correction_request(eval_request)
 
     @classmethod
     def create_eval_request(cls, application_id, application_ref_name, session_id, reference_id, action_type,
@@ -91,17 +92,18 @@ class Evaluator(MaitaiClient):
         eval_request.action_type = action_type
         if fault_description:
             eval_request.fault_description = fault_description
-        eval_request.client_version = cls.VERSION
         return eval_request
 
     @classmethod
     async def send_evaluation_request_async(cls, eval_request: EvaluateRequest, callback: EvaluateCallback = None):
         async def send_request():
+            path = "request" if callback else "submit"
             host = config.maitai_host
-            url = f'{host}/evaluation/request'
+            url = f'{host}/evaluation/{path}'
             headers = {
                 'Content-Type': 'application/json',
-                'x-api-key': config.api_key
+                'x-api-key': config.api_key,
+                'x-client-version': version,
             }
             async with aiohttp.ClientSession(connector=aiohttp.TCPConnector(ssl=False)) as session:
                 async with session.post(url, headers=headers,
@@ -124,18 +126,19 @@ class Evaluator(MaitaiClient):
                 return eval_result
 
     @classmethod
-    def send_realtime_eval_request(cls, eval_request: EvaluateRequest) -> Iterable[ChatCompletionChunk]:
+    def send_stream_correction_request(cls, eval_request: EvaluateRequest) -> Iterable[ChatCompletionChunk]:
         def consume_stream():
             host = config.maitai_host
-            url = f'{host}/evaluation/realtime'
+            url = f'{host}/evaluation/stream_correction'
             headers = {
                 'Content-Type': 'application/json',
-                'x-api-key': config.api_key
+                'x-api-key': config.api_key,
+                'x-client-version': version,
             }
 
-            response = requests.post(url, headers=headers, data=eval_request.to_json(casing=Casing.SNAKE), verify=False, stream=True)
+            response = requests.post(url, headers=headers, data=eval_request.to_json(casing=Casing.SNAKE), stream=True)
             if response.status_code != 200:
-                print(f"Failed to send realtime evaluation request. Status code: {response.status_code}. Error: {response.text}")
+                print(f"Failed to send stream correction request. Status code: {response.status_code}. Error: {response.text}")
                 return
             try:
                 for line in response.iter_lines():
