@@ -39,15 +39,15 @@ class MaitaiOpenAIClient:
         _strict_response_validation: bool = False,
     ):
         if api_key:
-            raise ValueError("The api_key parameter is not supported by Maitai. Provide openai_api_key or groq_api_key instead")
+            print("Warning: The api_key parameter is not supported by Maitai. Provide openai_api_key or groq_api_key instead")
         if maitai_api_key:
             config.initialize(maitai_api_key)
         if openai_api_key:
-            config.auth_info.openai_api_key = openai_api_key
+            config.auth_keys.openai_api_key.key_value = openai_api_key
         if groq_api_key:
-            config.auth_info.groq_api_key = groq_api_key
+            config.auth_keys.groq_api_key.key_value = groq_api_key
         self.client = openai.OpenAI(
-            api_key=api_key,
+            api_key=api_key or openai_api_key,
             organization=organization,
             project=project,
             base_url=base_url,
